@@ -1,10 +1,10 @@
-from .darkknight import Darkknight
+from .darkknight import DarkKnight
 from .ftp import Ftp
 from .ftps import Ftps
 from .geolocator import GeoLocator
 from .git import Git
 from .google_spreadsheet import GoogleSpreadsheet
-from .healthCheck import HealthCheck
+from .healthcheck import HealthCheck
 from .email import Email
 from .mongo import Mongo
 from .pdf import Pdf
@@ -15,7 +15,7 @@ from .toucan import Toucan
 from .pandas_extra import PandasExtra
 
 
-darkknight = Darkknight
+darkknight = DarkKnight
 ftp = Ftp
 git = Git
 ftps = Ftps
